@@ -10,8 +10,8 @@ from .limit_config import LimitConfig, Limit
 
 
 def create_ratelimit_decorator(engine: LimiterEngine, error_handler: LimiterErrorHandler):
-    def ratelimit(key: str, limits: List[Limit]):
-        config = LimitConfig(key, limits)
+    def ratelimit(key: str, *args: Limit):
+        config = LimitConfig(key, args)
 
         def decorator(func):
             @wraps(func)
