@@ -10,7 +10,7 @@ from .limiter_engine import LimiterEngine
 
 def create_ratelimit_depends(engine: LimiterEngine, error_handler: LimiterErrorHandler):
     def ratelimit(key: str, *args: Limit) -> Depends:
-        config = LimitConfig(key, *args)
+        config = LimitConfig(key, args)
 
         async def call(request: Request):
             limit_result = await engine.limit(config, request)
